@@ -72,8 +72,8 @@ def fastjet_clusters(
         Jet transverse momentum threshold. Jets with :math:`p_T` below
         this are discarded.
     eta_cut : float, optional
-        Jet pseudorapidity, :math:`eta`, threshold. Jets with
-        :math:`|eta|` above this are discarded.
+        Jet pseudorapidity, :math:`\\eta`, threshold. Jets with
+        :math:`|\\eta|` above this are discarded.
     top_k : int, optional
         Only return a maximum ``top_k`` number of jets, sorted by
         transverse momentum. *ie.* if ``top_k`` is 3, only 3 jets with
@@ -204,12 +204,16 @@ def find_vertex(
 
 def vertex_descendants(adj: gcl.AdjacencyList, vertex: int) -> gcl.MaskArray:
     """Returns a ``MaskArray`` to select particles which descend from a
-    given interaction vertex.
+    given interaction vertex. This mask includes the parent vertex.
 
     :group: select
 
     .. versionadded:: 0.1.0
 
+    .. versionchanged:: 0.2.7
+       In the edge case of no descendants, now returns a mask with just
+       the parent, rather than raising an unhandled ``IndexError``.
+
     Parameters
     ----------
     adj : AdjacencyList
@@ -223,8 +227,11 @@ def vertex_descendants(adj: gcl.AdjacencyList, vertex: int) -> gcl.MaskArray:
         Boolean mask over the graphicle objects associated with the
         passed AdjacencyList.
     """
+    vertex_mask = adj.edges["in"] == vertex
+    if not np.any(vertex_mask):
+        return gcl.MaskArray(adj.edges["out"] == vertex)
     sparse = adj._sparse_signed
-    vertex = sparse.row[vertex == adj.edges["in"]][0]
+    vertex = sparse.row[vertex_mask][0]
     bft = breadth_first_tree(sparse, vertex)
     mask = np.isin(sparse.row, bft.indices)
     mask[sparse.row == vertex] = True  # include parent vertex
@@ -414,6 +421,7 @@ def _hard_ancestor_matrix(hard_desc: gcl.MaskGroup) -> base.BoolVector:
     mat = np.zeros((num_hard, num_hard), dtype="<?")
     for i, mask in enumerate(hard_desc.values()):
         mat[i, :] = mask.data
+    np.fill_diagonal(mat, False)  # no self-parenting
     return mat
 
 
